SentryErrorExporter class final

Exports Obsi error reports through the Sentry Dart SDK.

Constructors

SentryErrorExporter({SentryCapture? capture, Future<void> close()?, bool closeOnShutdown = false, bool requireEventId = true})
Creates a instance.

Properties

closeOnShutdown bool
The close on shutdown.
final
exportedReports int
The exported reports.
no setter
hashCode int
The hash code for this object.
no setterinherited
rejectedReports int
The rejected reports.
no setter
requireEventId bool
The require event id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

export(ErrorReport report) Future<void>
Performs export.
forceFlush() Future<void>
Performs force flush.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() Future<void>
Performs shutdown.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited